@@ -244,10 +244,10 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
            "&brokerport="+str(brokerport)+"&enabletls="+str(enabletls))
     loop = asyncio.get_event_loop()
 #    future = asyncio.wait_for(loop.run_in_executor(None, time.sleep, 2), timeout)
-    try:
-       val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
-    except Exception as e:
-       print(e) 
+#    try:
+    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
+ #   except Exception as e:
+  #     print(e) 
     return val
 
 def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
